==> risk-center-api-0.0.1.6-sources.jar: cn/com/duiba/tuia/risk/center/api/dto/RiskExampleDto.java <==
package cn.com.duiba.tuia.risk.center.api.dto;/**
 * Created by chengdeman .
 * 18/2/27 .
 */

import java.io.Serializable;
import java.util.Date;

/**
 * 案例库表dto
 *
 * @author chengdeman
 * @create 2018-02-27 下午5:34
 **/
public class RiskExampleDto implements Serializable{


    private static final long serialVersionUID = 2031504238808215799L;

    /**
     * 主键ID
     */
    private Long id;

    private Long slotId;
    private String slotName;
    private Long appId;
    private String appName;
    private Date exceptionDate;

    /**
     * 最全宽表主键ID
     */
    private Long  riskAllId;

    /**
     * 审核表id
     */
    private Long riskReviewId;

    /**
     * 累计处理次数
     */
    private Long reviewCount;

    /**
     * 案例特征
     */
    private String exampleFeatures;

    /**
     * 案例需求
     */
    private String exampleDemand;

    /**
     * 案例结果
     */
    private String exampleResult;

    /**
     * 案例状态
     */
    private Integer exampleStatus;

    public Integer getExampleStatus() {
        return exampleStatus;
    }

    public void setExampleStatus(Integer exampleStatus) {
        this.exampleStatus = exampleStatus;
    }


    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public Long getRiskAllId() {
        return riskAllId;
    }

    public void setRiskAllId(Long riskAllId) {
        this.riskAllId = riskAllId;
    }

    public Long getRiskReviewId() {
        return riskReviewId;
    }

    public void setRiskReviewId(Long riskReviewId) {
        this.riskReviewId = riskReviewId;
    }

    public Long getReviewCount() {
        return reviewCount;
    }

    public void setReviewCount(Long reviewCount) {
        this.reviewCount = reviewCount;
    }

    public String getExampleFeatures() {
        return exampleFeatures;
    }

    public void setExampleFeatures(String exampleFeatures) {
        this.exampleFeatures = exampleFeatures;
    }

    public String getExampleDemand() {
        return exampleDemand;
    }

    public void setExampleDemand(String exampleDemand) {
        this.exampleDemand = exampleDemand;
    }

    public String getExampleResult() {
        return exampleResult;
    }

    public void setExampleResult(String exampleResult) {
        this.exampleResult = exampleResult;
    }

	public Date getExceptionDate() {
		return exceptionDate;
	}

	public void setExceptionDate(Date exceptionDate) {
		this.exceptionDate = exceptionDate;
	}

	public Long getSlotId() {
		return slotId;
	}

	public void setSlotId(Long slotId) {
		this.slotId = slotId;
	}

	public String getSlotName() {
		return slotName;
	}

	public void setSlotName(String slotName) {
		this.slotName = slotName;
	}

	public Long getAppId() {
		return appId;
	}

	public void setAppId(Long appId) {
		this.appId = appId;
	}

	public String getAppName() {
		return appName;
	}

	public void setAppName(String appName) {
		this.appName = appName;
	}
}

==> risk-center-api-0.4.1-20180823.045753-7-sources.jar: cn/com/duiba/tuia/risk/center/api/dto/RiskExampleDto.java <==
package cn.com.duiba.tuia.risk.center.api.dto;/**
 * Created by chengdeman .
 * 18/2/27 .
 */

import java.io.Serializable;
import java.util.Date;
import java.util.List;

import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;
import org.springframework.format.annotation.DateTimeFormat;

/**
 * 案例库表dto
 *
 * @author chengdeman
 * @create 2018-02-27 下午5:34
 **/
@ApiModel
public class RiskExampleDto implements Serializable{


    private static final long serialVersionUID = 2031504238808215799L;

    /**
     * 主键ID
     */
    private Long id;

    private Long slotId;
    private String slotName;
    private Long appId;
    private String appName;
    @DateTimeFormat(pattern = "yyyy-MM-dd")
    private Date exceptionDate;

    /**
     * 最全宽表主键ID
     */
    private Long  riskAllId;

    /**
     * 审核表id
     */
    private Long riskReviewId;

    /**
     * 累计处理次数
     */
    private Long reviewCount;

    /**
     * 案例特征
     */
    private String exampleFeatures;

    /**
     * 案例需求
     */
    private String exampleDemand;

    /**
     * 案例结果
     */
    private String exampleResult;

    /**
     * 案例状态
     */
    private Integer exampleStatus;

    @ApiModelProperty("案例下的图片")
    private List<Img> imgs;
	// 增加的图片urld
	@ApiModelProperty("需要添加的图片")
    private List<String> url2Add;
    // 删除的图片id
	@ApiModelProperty("需要删除的图片id")
    private List<Long> imgIds;

    public Integer getExampleStatus() {
        return exampleStatus;
    }

    public void setExampleStatus(Integer exampleStatus) {
        this.exampleStatus = exampleStatus;
    }


    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public Long getRiskAllId() {
        return riskAllId;
    }

    public void setRiskAllId(Long riskAllId) {
        this.riskAllId = riskAllId;
    }

    public Long getRiskReviewId() {
        return riskReviewId;
    }

    public void setRiskReviewId(Long riskReviewId) {
        this.riskReviewId = riskReviewId;
    }

    public Long getReviewCount() {
        return reviewCount;
    }

    public void setReviewCount(Long reviewCount) {
        this.reviewCount = reviewCount;
    }

    public String getExampleFeatures() {
        return exampleFeatures;
    }

    public void setExampleFeatures(String exampleFeatures) {
        this.exampleFeatures = exampleFeatures;
    }

    public String getExampleDemand() {
        return exampleDemand;
    }

    public void setExampleDemand(String exampleDemand) {
        this.exampleDemand = exampleDemand;
    }

    public String getExampleResult() {
        return exampleResult;
    }

    public void setExampleResult(String exampleResult) {
        this.exampleResult = exampleResult;
    }

	public Date getExceptionDate() {
		return exceptionDate;
	}

	public void setExceptionDate(Date exceptionDate) {
		this.exceptionDate = exceptionDate;
	}

	public Long getSlotId() {
		return slotId;
	}

	public void setSlotId(Long slotId) {
		this.slotId = slotId;
	}

	public String getSlotName() {
		return slotName;
	}

	public void setSlotName(String slotName) {
		this.slotName = slotName;
	}

	public Long getAppId() {
		return appId;
	}

	public void setAppId(Long appId) {
		this.appId = appId;
	}

	public String getAppName() {
		return appName;
	}

	public void setAppName(String appName) {
		this.appName = appName;
	}

	public List<Img> getImgs() {
		return imgs;
	}

	public void setImgs(List<Img> imgs) {
		this.imgs = imgs;
	}

	public List<Long> getImgIds() {
		return imgIds;
	}

	public void setImgIds(List<Long> imgIds) {
		this.imgIds = imgIds;
	}

	public List<String> getUrl2Add() {
		return url2Add;
	}

	public void setUrl2Add(List<String> url2Add) {
		this.url2Add = url2Add;
	}
}
